Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
RootCmd represents the base command when called without any subcommands.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
Types ¶
This section is empty.
Source Files
¶
- cache.go
- compile.go
- helper.go
- host.go
- override.go
- regex.go
- root.go
- server.go
- status.go
- version.go
Click to show internal directories.
Click to hide internal directories.